#!/bin/sh
# simple gui by radky for Michael Amadio's Pmcputemp monitor

export TEXTDOMAIN=cputemp
export OUTPUT_CHARSET=UTF-8

export VERSION=1.0
 
CONFIG="$HOME/.config/pmcputemp"
[ ! -d $CONFIG ] && mkdir -p $CONFIG

COLOR=`cat $CONFIG/color 2>/dev/null`
[ -z $COLOR ] && COLOR=blue-green && echo "$COLOR" > $CONFIG/color

DELAY=`cat $CONFIG/delay 2>/dev/null`
[ -z $DELAY ] && DELAY=5 && echo "$DELAY" > $CONFIG/delay

[ ! -f /usr/share/icons/hicolor/scalable/apps/pmcputemp.svg ] && \
ln -sf /usr/share/icons/pmcputemp.svg /usr/share/icons/hicolor/scalable/apps && gtk-update-icon-cache -f -i /usr/share/icons/hicolor 2>/dev/null

# start pmcputemp
start_pmcputemp(){
	if [ "$COLOR" = "dark-gray" ]; then
	   COLOR=d
	elif [ "$COLOR" = "light-gray" ]; then
	   COLOR=l
	else
	   COLOR=""
	fi
	gtkdialog-splash -timeout 3 -margin 10 -placement top -fontsize large -bg goldenrod -text " $(gettext 'Temperature monitor started') " &
	pmcputempPID=$(pgrep pmcputemp)
	[ -n "$pmcputempPID" ] && kill -9 $pmcputempPID &
	sleep 0.5
	exec pmcputemp $COLOR $DELAY
}
export -f start_pmcputemp

# stop pmcputemp
stop_pmcputemp(){
	gtkdialog-splash -timeout 3 -margin 10 -placement top -fontsize large -bg goldenrod -text " $(gettext 'Temperature monitor stopped') " &
	pmcputempPID=$(pgrep pmcputemp)
	[ -n "$pmcputempPID" ] && kill -9 $pmcputempPID &
}
export -f stop_pmcputemp

# add pmcputemp autostart
add_autostart(){
	gtkdialog-splash -timeout 3 -margin 10 -placement top -fontsize large -bg goldenrod -text " $(gettext 'Adding autostart at boot') " &
	if [ "$COLOR" = "dark-gray" ]; then
	   COLOR=d
	elif [ "$COLOR" = "light-gray" ]; then
	   COLOR=l
	else
	   COLOR=""
	fi
	echo '#!/bin/sh
pmcputemp '"$COLOR $DELAY"'' > $HOME/Startup/pmcputemp-start
	chmod +x $HOME/Startup/pmcputemp-start
}
export -f add_autostart

# remove pmcputemp autostart
remove_autostart(){
	gtkdialog-splash -timeout 3 -margin 10 -placement top -fontsize large -bg goldenrod -text " $(gettext 'Removing autostart at boot') " &
	rm -f $HOME/Startup/pmcputemp* &
}
export -f remove_autostart

MAIN_DIALOG='
<window title="Pmcputemp-'$VERSION'" icon-name="pmcputemp" resizable="false" window-position="1">
	<vbox margin="5" space-expand="false" space-fill="false">
		<vbox>
			<pixmap>
				<height>75</height>
				<width>75</width>
				<input file icon="pmcputemp"></input>
			</pixmap>
			<text use-markup="true" homogeneous="true" space-expand="false" space-fill="false"><label>"                              '"<b><span size='"'large'"'>$(gettext 'CPU Temperature Monitor')</span></b>"'                              "</label></text>
			<hseparator space-expand="false" space-fill="false"></hseparator>
			<hbox homogeneous="true" space-expand="true" space-fill="true">
				<vbox space-expand="true" space-fill="true">
					<button tooltip-text=" '"$(gettext "Start CPU Temperature Monitor")"' ">
						<label>"'"$(gettext "Start / Restart")"'"</label>
						<action>start_pmcputemp &</action>
					</button>
				</vbox>
				<vbox space-expand="true" space-fill="true">
					<button tooltip-text=" '"$(gettext "Stop CPU Temperature Monitor")"' ">
						<label>"'"$(gettext "Stop")"'"</label>
						<action>stop_pmcputemp &</action>
					</button>
				</vbox>
			</hbox>

			<hbox homogeneous="true" space-expand="true" space-fill="true">
				<vbox space-expand="true" space-fill="true">
					<button tooltip-text=" '"$(gettext "Start CPU Temperature Monitor at boot")"' ">
						<label>"'"$(gettext "Autostart  ON")"'"</label>
						<action>add_autostart &</action>
					</button>
				</vbox>
				<vbox space-expand="true" space-fill="true">
					<button tooltip-text=" '"$(gettext "Remove start at boot")"' ">
						<label>"'"$(gettext "Autostart  OFF")"'"</label>
						<action>remove_autostart &</action>
					</button>
				</vbox>
			</hbox>
		</vbox>

		<vbox margin="10" space-expand="true" space-fill="true">
		  <hbox homogeneous="true" space-expand="false" space-fill="true">
		  <vbox homogeneous="true" space-expand="false" space-fill="true">
			<text><label>'"$(gettext 'Color')"'</label></text>
			<hbox homogeneous="true" space-expand="false">
				<comboboxtext width-request="200" wrap="false" tooltip-text=" '"$(gettext "Background color of temperature monitor")"' ">
					<variable>COLOR</variable>
					<default>'$COLOR'</default>
					<item>blue-green</item>
					<item>dark-gray</item>
					<item>light-gray</item>
					<action>echo "$COLOR" > '$CONFIG'/color</action>
				</comboboxtext>
			</hbox>
		  </vbox>
		  <vbox homogeneous="true" space-expand="false" space-fill="true">
			<text><label>'"$(gettext 'Delay')"'</label></text>
			<hbox homogeneous="true" space-expand="false">
				<comboboxtext width-request="200" wrap="false" tooltip-text=" '"$(gettext "Refresh interval in seconds  (Default:5)")"' ">
					<variable>DELAY</variable>
					<default>'$DELAY'</default>
					<item>1</item>
					<item>2</item>
					<item>3</item>
					<item>4</item>
					<item>5</item>
					<item>6</item>
					<item>7</item>
					<item>8</item>
					<item>9</item>
					<item>10</item>
					<action>echo "$DELAY" > '$CONFIG'/delay</action>
				</comboboxtext>
			</hbox>
		  </vbox>
		  </hbox>
		</vbox>

		<hseparator space-expand="false" space-fill="false"></hseparator>

		<hbox homogeneous="true" space-expand="true" space-fill="true">
			<button space-expand="true" space-fill="true" tooltip-text=" '"$(gettext "View current status of temperature sensors")"' ">
				<label>'$(gettext 'Sensor Status')'</label>
				<action>sensor-status &</action>
			</button>
			<button space-expand="true" space-fill="true" tooltip-text=" '"$(gettext "Select sensor for temperature monitor")"' ">
				<label>'$(gettext 'Select Sensor')'</label>
				<action>sensor-select &</action>
			</button>
			<button space-expand="true" space-fill="true">
				<label>'$(gettext 'Quit')'</label>
				<action>exit:quit_now</action>
			</button>
		</hbox>
	</vbox>
</window>'

export MAIN_DIALOG

case $1 in
	-d | --dump) echo "$MAIN_DIALOG" ;;
	*) gtkdialog --program=MAIN_DIALOG ;;
esac
